@@ -29,11 +29,11 @@ impl Config {
     const DEFAULT_CONSOLE: &'static str = "https://console.statehub.io";
 
     pub(crate) fn api(&self) -> &str {
-        self.api.as_str()
+        self.api.as_str().trim().trim_end_matches('/')
     }
 
     pub(crate) fn console(&self) -> &str {
-        self.console.as_str()
+        self.console.as_str().trim().trim_end_matches('/')
     }
 
     pub(crate) fn optionally_management_api(self, api: Option<String>) -> Self {
